/*
 *  src/GUI/StatsDialog.cs
 *  Copyright (C) 2007 by Marcin Krystian Krzywonos
 *  License: GNU/GPL version 2
 */


using System;
using Gtk;
using Mono.Unix;
using Incollector.Engine;
using System.Collections;


namespace Incollector.GUI {

	/*
	 * StatsDialog class
	 */
	
	public class StatsDialog : Gtk.Dialog {
		
		private Gtk.ListStore store;
		
		public StatsDialog (Gtk.Window parent)
		{
			this.Title        = Catalog.GetString ("Stats");
			this.Resizable    = false;
			this.HasSeparator = false;
			this.BorderWidth  = 8;
			this.VBox.Spacing = 8;
			this.TransientFor = parent;
			
			Incollector.GUI.Icons.AssignWindow (this);
			
			
			// MainBox
			Gtk.VBox MainBox = new Gtk.VBox ();
			this.VBox.Add (MainBox);
			
			
			// StatsList and scroll
			Gtk.ScrolledWindow scroll = new Gtk.ScrolledWindow ();
			scroll.SetPolicy (Gtk.PolicyType.Automatic, Gtk.PolicyType.Automatic); 
			scroll.ShadowType = Gtk.ShadowType.In;
			
			Gtk.TreeView StatsList  = new Gtk.TreeView ();
			StatsList.RulesHint     = true;
			StatsList.WidthRequest  = 250;
			StatsList.HeightRequest = 240;
			scroll.Add (StatsList);
			
			store = new Gtk.ListStore (typeof (string), typeof (string));
			StatsList.Model = store;
			
			StatsList.AppendColumn (Catalog.GetString ("Data type"), new CellRendererText (), "markup", 0);
			StatsList.AppendColumn (Catalog.GetString ("Entries"), new CellRendererText (), "markup", 1);
			
			MainBox.Add (scroll);
			
			
			// CloseBtn
			Gtk.Button CloseBtn = new Gtk.Button (Catalog.GetString ("_Close"));
			CloseBtn.Clicked += new EventHandler (on_CloseBtn_clicked);
			
			Gtk.Image img = new Gtk.Image ();
			img.IconName = Gtk.Stock.Close;
			CloseBtn.Image = img;
			this.ActionArea.Add (CloseBtn);
			
			
			// Creating stats
			this.Sensitive = false;
			CreateStats ();
			this.Sensitive = true;
			
			
			this.ShowAll ();
		}
		
		
		struct dtype {
			public string name;
			public int    count;
		}
		
		
		private void CreateStats ()
		{
			ArrayList list = new ArrayList ();
			int       i, all = 0;
			
			foreach (Engine.EntryStruct ent in DB.Data) {
				i = 0;
				foreach (dtype type in list) {
					if (type.name == ent.data.Title) {
						type.count++;
						list [i] = type;
						all++;
						goto ok;
					}
					
					i++;
				}
				
				dtype tpe = new dtype ();
				tpe.name  = ent.data.Title;
				tpe.count = 1;
				all++;
				list.Add (tpe);
				
				ok:
					;
			}
			
			
			foreach (dtype type in list)
				store.AppendValues (new object [] { Text.PrepareText (type.name, false),
													type.count.ToString () });
			
			store.AppendValues (new object [] { "", "" });
			store.AppendValues (new object [] { "<b>" + Catalog.GetString ("Total") + "</b>",
												"<b>" + all.ToString () + "</b>" });
		}
		
		
		protected void on_CloseBtn_clicked (object o, EventArgs args)
		{
			this.Respond (ResponseType.Close);
		}
	}
}
