/*
 * Incollector
 * version 1.2
 * Copyright (C) 2006-2008 by Marcin Krystian Krzywonos
 * License: GNU/GPL version 2
 */


using System;
using System.IO;
using Gtk;
using Incollector.Engine;
using Mono.Unix;
using Mono.Unix.Native;
using Incollector.GUI;
using System.Runtime.InteropServices;



namespace Incollector {

	/// <summary>Global objects and functions</summary>
	/// <remarks>The class is decribed in src/Main.cs file.</remarks>
	public static class Global {
		/// <summary>Main window object.</summary>
		/// <remarks>Created in Main function on application start.</remarks>
		public static MainWindow MainWindowObject;
	}


	public class MainClass {
		
		
		[DllImport("libc")]
		private static extern int prctl(int option, string name, ulong a3, ulong a4, ulong a5);
		
		
		static public void  Main (string [] args)
		{
			// process name
			try {
				prctl (15, "incollector", 0, 0, 0);
			} catch {
			}
		
			// exit signal
			try {
				Syscall.signal (Signum.SIGTERM, on_Application_exit);
				Syscall.signal (Signum.SIGQUIT, on_Application_exit);
				Syscall.signal (Signum.SIGKILL, on_Application_exit);
			} catch {
			}
			
			
			Engine.FilesPaths.CheckHomeDir ();
			Engine.FilesPaths.MoveSavings();
			
			// Loading gtk+ theme (if win system)
			if (FilesPaths.IsWinSystem () == true) {
				try {
					// if engine' file doesn't exist, install it !
					foreach (string file in System.IO.Directory.GetFiles ("theme"))
						if (Path.GetExtension (file) == ".dll") {
							try {
								File.Copy (file, Path.Combine (Gtk.Rc.ModuleDir, Path.GetFileName (file)));
							} catch {
							}
						}
					
					// Loading theme
					Gtk.Rc.Parse (Path.Combine (System.AppDomain.CurrentDomain.BaseDirectory, "theme\\gtk-2.0\\gtkrc"));
				} catch {
					System.Console.WriteLine ("GTK+ theme couldn't load.");
				}
			}
			
			// Loading translate
			if (FilesPaths.IsWinSystem () == true)
				Mono.Unix.Catalog.Init ("incollector", Path.Combine (System.AppDomain.CurrentDomain.BaseDirectory, "..\\share\\locale"));
			else
				if (Directory.Exists (Path.Combine (System.AppDomain.CurrentDomain.BaseDirectory, "../../share/locale")))
					Mono.Unix.Catalog.Init ("incollector", Path.Combine (System.AppDomain.CurrentDomain.BaseDirectory, "../../share/locale"));
				else
					Mono.Unix.Catalog.Init ("incollector", Path.Combine (System.AppDomain.CurrentDomain.BaseDirectory, Defines.LocaleDir));
			
			Engine.EntryStruct.UNTAGGED = Catalog.GetString ("Untagged");
			
			Application.Init ();
			Colors.Init();
			Engine.Settings.Load ();

			// First start
			if (Engine.FilesPaths.SettingsFileExists == false)
				Engine.Settings.LoadDefaultSettings ();

			Globals.Init (args);
			Application.Run ();
		}
		
		
		static void on_Application_exit (int signal)
		{
			Global.MainWindowObject.ExitApplication ();
			System.Environment.Exit (0);
		}
	}	
}
