/*
 *  Types/Note.cs
 *  Copyright (C) 2006-2007 Marcin Krystian Krzywonos
 *  License: GNU/GPL version 2
 */


using System;
using System.Xml;
using System.Reflection;
using Incollector.GUI.Widgets;
using Gtk;
using Mono.Unix;


namespace Incollector.DataTypes {
	
	public class SerialNumber : DataType {
		
		protected static Gtk.Entry ApplicationWidget = new Gtk.Entry ();
		protected static Gtk.Entry NumberWidget = new Gtk.Entry ();
		
		protected string _DataApplication = "";
		protected string _DataNumber = "";
		
		protected string DataApplication {
			get { return this._DataApplication;  }
			set { this._DataApplication = value; }
		}
		
		protected string DataNumber {
			get { return this._DataNumber;  }
			set { this._DataNumber = value; }
		}
		
	
	
		public override string Name {
			get { return "serial"; }
		}
		
		public override string Title {
			get { return Catalog.GetString ("Serial number"); }
		}
		
		public override string MenuText {
			get { return Catalog.GetString ("Add a serial number"); }
		}
		
		public override Gtk.Widget DefaultFocusWidget {
			get { return ApplicationWidget; }
		}
		
		public override Gtk.Widget FocusWidget {
			get { return ApplicationWidget; }
		}
		
		public override Gtk.Widget EditWidget {
			get {
				Gtk.Table tbl = new Gtk.Table (2, 2, false);
				
				Gtk.Label lbl1 = new Gtk.Label (Catalog.GetString ("Application"));
				lbl1.Xalign = 1;
				lbl1.Yalign = (float) 0.50;
				tbl.Attach (lbl1, 0, 1, 0, 1, AttachOptions.Fill,
							AttachOptions.Fill, 3, 3);
				
				ApplicationWidget = new Gtk.Entry ();
				ApplicationWidget.Text = this.DataApplication;
				Incollector.Engine.Autocompletion.Assign (ApplicationWidget, "data:" +
																Name + ":application");
				tbl.Attach (ApplicationWidget, 1, 2, 0, 1,
							AttachOptions.Expand | AttachOptions.Fill,
							AttachOptions.Shrink | AttachOptions.Fill, 3, 3);
				
				Gtk.Label lbl2 = new Gtk.Label (Catalog.GetString ("Number"));
				lbl2.Xalign = 1;
				lbl2.Yalign = (float) 0.50;
				tbl.Attach (lbl2, 0, 1, 1, 2, AttachOptions.Fill,
							AttachOptions.Fill, 3, 3);
				
				NumberWidget = new Gtk.Entry ();
				NumberWidget.Text = this.DataNumber;
				Incollector.Engine.Autocompletion.Assign (NumberWidget, "data:" + Name + ":number");
				tbl.Attach (NumberWidget, 1, 2, 1, 2,
							AttachOptions.Expand | AttachOptions.Fill,
							AttachOptions.Shrink | AttachOptions.Fill, 3, 3);
				
				tbl.ShowAll ();
				return tbl;
			}
		}
		
		public override string EditWidgetContent {
			set { this.DataNumber = value; }
		}
		
		public override Gtk.Widget PreviewWidget {
			get {
				Gtk.Table tbl = new Gtk.Table (2, 2, false);
				
				Gtk.Label lbl1 = new Gtk.Label ();
				lbl1.UseMarkup = true;
				lbl1.Markup    = "<b>" + Catalog.GetString ("Application") + "</b>";
				lbl1.Xalign    = 1;
				tbl.Attach (lbl1, 0, 1, 0, 1, AttachOptions.Fill,
							AttachOptions.Fill, 3, 3);
				
				PreviewLabel Application  = new PreviewLabel (this.DataApplication);
				Application.Xalign     = 0;
				Application.Yalign     = 0;
				tbl.Attach (Application, 1, 2, 0, 1, AttachOptions.Fill,AttachOptions.Fill, 3, 3);
				
				Gtk.Label lbl2 = new Gtk.Label ();
				lbl2.UseMarkup = true;
				lbl2.Markup    = "<b>" + Catalog.GetString ("Serial number") + "</b>";
				lbl2.Xalign    = 1;
				lbl2.Yalign    = 0;
				tbl.Attach (lbl2, 0, 1, 1, 2, AttachOptions.Fill, AttachOptions.Fill, 3, 3);
				
				PreviewLabel SerialNumber = new PreviewLabel (this.DataNumber);
				SerialNumber.Wrap = true;
				SerialNumber.Xalign = 0;
				SerialNumber.Yalign = 0;
				tbl.Attach (SerialNumber, 1, 2, 1, 2,
							AttachOptions.Expand | AttachOptions.Fill,
							AttachOptions.Expand | AttachOptions.Fill, 3, 3);
				
				tbl.ShowAll ();
				
				return tbl;
			}
		}
		
		public override string EntryTitle {
			get { return this.DataApplication; }
		}
		
		public override Gdk.Pixbuf Icon16 {
			get { return new Gdk.Pixbuf (Assembly.GetEntryAssembly (), "serialnumber-16.png"); }
		}
		
		public override Gdk.Pixbuf Icon32 {
			get { return new Gdk.Pixbuf (Assembly.GetEntryAssembly (), "serialnumber-32.png"); }
		}
		
		public override Gdk.Pixbuf Icon48 {
			get { return new Gdk.Pixbuf (Assembly.GetEntryAssembly (), "serialnumber-48.png"); }
		}
		
		
		
		public SerialNumber ()
		{
		}
		
		
		public override DataType New ()
		{
			return new SerialNumber ();
		}
		
		
		public override DataType Clone ()
		{
			SerialNumber srl = new SerialNumber ();
			
			srl._DataApplication = this._DataApplication.Clone () as string;
			srl._DataNumber = this._DataNumber.Clone () as string;
			
			return srl;
		}
		

		public override void ReadXml (XmlTextReader reader)
		{
			this.DataApplication = reader.GetAttribute ("application");
			this.DataNumber      = reader.ReadString ();
			
			Incollector.Engine.Autocompletion.Add ("data:" + Name + ":application", this.DataApplication);
			Incollector.Engine.Autocompletion.Add ("data:" + Name + ":number", this.DataNumber);
		}
		
		
		public override void WriteXml (XmlTextWriter writer)
		{
			writer.WriteStartElement (Name);
				writer.WriteAttributeString ("application", this.DataApplication);
				writer.WriteString (this.DataNumber);
			writer.WriteEndElement ();
		}
		
		
		public override void AddChangedEvent (EventHandler hdlr)
		{
			ApplicationWidget.Changed += hdlr;
			NumberWidget.Changed      += hdlr;
		}
		
		
		public override bool Search (string query)
		{
			return Engine.Text.Search (query, this.DataApplication) || Engine.Text.Search (query, this.DataNumber);
		}
		
		
		public override bool IsFormFilledIn ()
		{
			return (ApplicationWidget.Text != "") && (NumberWidget.Text != "");
		}
		
		
		public override void SynchronizeData ()
		{
			this.DataApplication = ApplicationWidget.Text;
			this.DataNumber = NumberWidget.Text;
		}

	}
}
